@@ -6,8 +6,7 @@ from typing import Dict, List
 from uuid import uuid4
 
 from instagrapi import config
-from instagrapi.exceptions import (ClientError, IGTVConfigureError,
-                                   IGTVNotUpload)
+from instagrapi.exceptions import ClientError, IGTVConfigureError, IGTVNotUpload
 from instagrapi.extractors import extract_media_v1
 from instagrapi.types import Location, Media, Usertag
 
